abacusai.holdout_analysis — AbacusAI documentation

# abacusai.holdout_analysis

## Classes

`HoldoutAnalysis` | A holdout analysis object.

## Module Contents

class abacusai.holdout_analysis.HoldoutAnalysis(client, holdoutAnalysisId=None, name=None, featureGroupIds=None, modelId=None, modelName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A holdout analysis object.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - holdoutAnalysisId (str) – The unique identifier of the holdout analysis.

    - name (str) – The name of the holdout analysis.

    - featureGroupIds (list[str]) – The feature group ids associated with the holdout analysis.

    - modelId (str) – The model id associated with the holdout analysis.

    - modelName (str) – The model name associated with the holdout analysis.

  holdout_analysis_id
  name
  feature_group_ids
  model_id
  model_name
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  rerun(model_version=None, algorithm=None)

    Rerun a holdout analysis. A different model version and algorithm can be specified which should be under the same model.

    Parameters:

      - model_version (str) – (optional) Version of the model to use for the holdout analysis

      - algorithm (str) – (optional) ID of algorithm to use for the holdout analysis

    Returns:

      The created holdout analysis version

    Return type:

      HoldoutAnalysisVersion

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      HoldoutAnalysis

  describe()

    Get a holdout analysis.

    Parameters:

      holdout_analysis_id (str) – ID of the holdout analysis to get

    Returns:

      The holdout analysis

    Return type:

      HoldoutAnalysis

  list_versions()

    List holdout analysis versions for a holdout analysis.

    Parameters:

      holdout_analysis_id (str) – ID of the holdout analysis to list holdout analysis versions for

    Returns:

      The holdout analysis versions

    Return type:

      list[HoldoutAnalysisVersion]